==> style-o-matic-1.1.3.tgz: package/es/components/Table/Table.js <==
var _class, _temp, _initialiseProps;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { cloneElement } from "react";
import cx from "classnames";
import { CoreComponent, getCorePropTypes, getCorePropDefaults, getValidProps, ROLE, uID } from "../../lib";
import TableHead from "./TableHead.js";
import TableBody from "./TableBody.js";
import TableFoot from "./TableFoot.js";
import TableRow from "./TableRow.js";
import TableCell from "./TableCell.js";
import TableData from "./models/TableData.js";
import Pagination from "../Pagination/Pagination.js";
import "./Table.css";

function ParseSectionData(data, UUID) {
  var output = [];
  var rowCount = data.length;
  var colCount = data[0].length;
  for (var i = 0; i < rowCount; i += 1) {
    var readRow = data[i];
    var dataRow = [];
    for (var x = 0; x < colCount; x += 1) {
      var column = readRow[x];
      if (column instanceof Object) {
        var content = column.content,
            props = _objectWithoutProperties(column, ["content"]);

        dataRow.push(React.createElement(
          TableCell,
          _extends({ key: "td_" + UUID + "_cell_" + i + x }, props),
          content
        ));
      } else {
        dataRow.push(React.createElement(
          TableCell,
          { key: "td_" + UUID + "_cell_" + i + x },
          column
        ));
      }
    }
    output.push(React.createElement(
      TableRow,
      { key: "td_" + UUID + "_cellrow" + i },
      dataRow
    ));
  }
  return output;
}

var Table = (_temp = _class = function (_CoreComponent) {
  _inherits(Table, _CoreComponent);

  function Table(props) {
    _classCallCheck(this, Table);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.columns = {};
    _this.data = TableData.init(_this);
    return _this;
  }

  /* eslint-disable */

  /* eslint-enable */

  Table.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        bordered = _getValidProps.bordered,
        padded = _getValidProps.padded,
        hover = _getValidProps.hover,
        spaced = _getValidProps.spaced,
        striped = _getValidProps.striped,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var classes = {
      "ui-table-bordered": bordered,
      "ui-table-padded": padded,
      "ui-table-hover": hover,
      "ui-table-spaced": spaced,
      "ui-table-striped": striped
    };

    var uiClassCore = cx(className, classes);
    delete props.className;

    var bodyRows = this.preRenderBody(children, inherited);

    return React.createElement(
      Component,
      _extends({ className: uiClassCore }, props),
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === TableHead.defaultProps.uirole) {
          return _this2.renderInteractiveChild(child, inherited);
        }
        return null;
      }),
      bodyRows,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole !== TableHead.defaultProps.uirole && child.props.uirole !== TableBody.defaultProps.uirole) {
          switch (child.props.uirole) {
            case TableFoot.defaultProps.uirole:
              return _this2.renderInteractiveChild(child, inherited);
            default:
              return child;
          }
        }
        return null;
      }),
      this.renderPagination()
    );
  };

  return Table;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  bordered: "bool",
  padded: "bool",
  hover: "bool",
  spaced: "bool",
  striped: "bool"
}), _class.defaultProps = getCorePropDefaults({
  renderAs: "table",
  uirole: ROLE.TABLE,
  bordered: false,
  padded: false,
  hover: false,
  spaced: false,
  striped: false
}), _class.Head = TableHead, _class.Body = TableBody, _class.Foot = TableFoot, _class.Row = TableRow, _class.Cell = TableCell, _class.FactoryData = function (data) {
  var output = [];
  var UUID = uID();
  if (data.head) {
    var compiled = ParseSectionData(data.head, UUID);
    output.push(React.createElement(
      TableHead,
      { key: "thead_" + UUID },
      compiled
    ));
  }
  if (data.body) {
    var _compiled = ParseSectionData(data.body, UUID);
    output.push(React.createElement(
      TableBody,
      { key: "tbody_" + UUID },
      _compiled
    ));
  }
  if (data.foot) {
    var _compiled2 = ParseSectionData(data.foot, UUID);
    output.push(React.createElement(
      TableFoot,
      { key: "tfoot_" + UUID },
      _compiled2
    ));
  }
  return output;
}, _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleFilter = function (node) {
    _this3.forceUpdate();
  };

  this.handleSort = function (node) {
    var _node$props = node.props,
        rowid = _node$props.rowid,
        columnid = _node$props.columnid;

    var dataColumn = _this3.data.getColumn(columnid);
    dataColumn.changeSortState();
    _this3.forceUpdate();
  };

  this.handleEdit = function (node) {
    _this3.forceUpdate();
  };

  this.handlePageChange = function (pageNum) {
    _this3.data.setPagination(pageNum);
    _this3.forceUpdate();
  };

  this.renderInteractiveChild = function (child, props) {
    var role = child.props.uirole;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      data: _this3.data,
      uiclass: _this3.childPrefix(child.props.uirole),
      filtering: _this3.handleFilter,
      sorting: _this3.handleSort,
      editing: _this3.handleEdit
    }));
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      data: _this3.data,
      uiclass: _this3.childPrefix(child.props.uirole)
    }));
  };

  this.preRenderBody = function (children, inherited) {
    var output = [];
    React.Children.map(children, function (child) {
      if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === TableBody.defaultProps.uirole) {
        output.push(_this3.renderChild(child, inherited));
      }
      return null;
    });
    return output;
  };

  this.renderPagination = function () {
    var output = [];
    if (_this3.props.pagination) {
      var pageConfig = _this3.data.getPagination();
      var uuid = _this3.props.uuid;

      output.push(React.createElement(
        TableFoot,
        { key: "tfoot_pagination_" + uuid, data: _this3.data },
        React.createElement(
          TableRow,
          { key: "td_pagination_" + uuid + "_cellrow" },
          React.createElement(
            TableCell,
            {
              key: "td_pagination_" + uuid + "_cell",
              colSpan: pageConfig.cols
            },
            React.createElement(Pagination, {
              pageTotal: pageConfig.pageTotal,
              pageNum: pageConfig.pageNum,
              onPageChange: _this3.handlePageChange
            })
          )
        )
      ));
    }
    return output;
  };
}, _temp);


export default Table;

==> style-o-matic-1.1.5.tgz: package/es/components/Table/Table.js <==
var _class, _temp, _initialiseProps;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { cloneElement } from "react";
import cx from "classnames";
import { CoreComponent, setCorePropTypes, setCorePropDefaults, getValidProps, ROLE, uID } from "../../lib";
import TableHead from "./TableHead.js";
import TableBody from "./TableBody.js";
import TableFoot from "./TableFoot.js";
import TableRow from "./TableRow.js";
import TableCell from "./TableCell.js";
import TableData from "./models/TableData.js";
import Pagination from "../Pagination/Pagination.js";
import "./Table.css";

function ParseSectionData(data, UUID, colSpan) {
  var output = [];
  var rowCount = data.length;
  for (var i = 0; i < rowCount; i += 1) {
    var readRow = data[i];
    var dataRow = [];
    for (var x = 0; x < colSpan; x += 1) {
      var column = readRow[x];
      if (column instanceof Object) {
        var content = column.content,
            props = _objectWithoutProperties(column, ["content"]);

        dataRow.push(React.createElement(
          TableCell,
          _extends({ key: "td_" + UUID + "_cell_" + i + x }, props),
          content
        ));
      } else {
        dataRow.push(React.createElement(
          TableCell,
          { key: "td_" + UUID + "_cell_" + i + x },
          column
        ));
      }
    }
    output.push(React.createElement(
      TableRow,
      { key: "td_" + UUID + "_cellrow" + i },
      dataRow
    ));
  }
  return output;
}

function ParseTableData(data) {
  var output = [];
  var UUID = uID();
  var colSpan = 0;
  if (data.head && data.head[0]) {
    colSpan = data.head[0].length;
    var compiled = ParseSectionData(data.head, UUID, colSpan);
    output.push(React.createElement(
      TableHead,
      { key: "thead_" + UUID },
      compiled
    ));
  }
  if (data.body && data.body[0]) {
    colSpan = colSpan === 0 ? data.body[0].length : colSpan;
    var _compiled = ParseSectionData(data.body, UUID, colSpan);
    output.push(React.createElement(
      TableBody,
      { key: "tbody_" + UUID },
      _compiled
    ));
  }
  if (data.foot && data.foot[0]) {
    colSpan = colSpan === 0 ? data.foot[0].length : colSpan;
    var _compiled2 = ParseSectionData(data.foot, UUID, colSpan);
    output.push(React.createElement(
      TableFoot,
      { key: "tfoot_" + UUID },
      _compiled2
    ));
  }
  return output;
}

var Table = (_temp = _class = function (_CoreComponent) {
  _inherits(Table, _CoreComponent);

  function Table(props) {
    _classCallCheck(this, Table);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.columns = {};
    _this.data = TableData.init(_this);
    return _this;
  }

  /* eslint-disable */

  /* eslint-enable */

  Table.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        bordered = _getValidProps.bordered,
        padded = _getValidProps.padded,
        hover = _getValidProps.hover,
        spaced = _getValidProps.spaced,
        striped = _getValidProps.striped,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var classes = {
      "ui-table-bordered": bordered,
      "ui-table-padded": padded,
      "ui-table-hover": hover,
      "ui-table-spaced": spaced,
      "ui-table-striped": striped
    };

    var uiClassCore = cx(className, classes);
    delete props.className;
    var tableContents = this.preParseChildren(children);

    var bodyRows = this.preRenderBody(tableContents, inherited);

    return React.createElement(
      Component,
      _extends({ className: uiClassCore }, props),
      React.Children.map(tableContents, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === TableHead.defaultProps.uirole) {
          return _this2.renderInteractiveChild(child, inherited);
        }
        return null;
      }),
      bodyRows,
      React.Children.map(tableContents, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole !== TableHead.defaultProps.uirole && child.props.uirole !== TableBody.defaultProps.uirole) {
          switch (child.props.uirole) {
            case TableFoot.defaultProps.uirole:
              return _this2.renderInteractiveChild(child, inherited);
            default:
              return child;
          }
        }
        return null;
      }),
      this.renderPagination()
    );
  };

  return Table;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  bordered: "bool",
  padded: "bool",
  hover: "bool",
  spaced: "bool",
  striped: "bool",
  pagination: "number"
}), _class.defaultProps = setCorePropDefaults({
  renderAs: "table",
  uirole: ROLE.TABLE,
  bordered: false,
  padded: false,
  hover: false,
  spaced: false,
  striped: false,
  pagination: null
}), _class.Head = TableHead, _class.Body = TableBody, _class.Foot = TableFoot, _class.Row = TableRow, _class.Cell = TableCell, _class.FactoryData = ParseTableData, _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleFilter = function (node) {
    _this3.forceUpdate();
  };

  this.handleSort = function (node) {
    var _node$props = node.props,
        rowid = _node$props.rowid,
        columnid = _node$props.columnid;

    var dataColumn = _this3.data.getColumn(columnid);
    dataColumn.changeSortState();
    _this3.forceUpdate();
  };

  this.handleEdit = function (node) {
    _this3.forceUpdate();
  };

  this.handlePageChange = function (pageNum) {
    _this3.data.setPagination(pageNum);
    _this3.forceUpdate();
  };

  this.preParseChildren = function (children) {
    if (children && (children.head || children.body || children.foot)) {
      return ParseTableData(children);
    }
    return children;
  };

  this.renderInteractiveChild = function (child, props) {
    var role = child.props.uirole;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      data: _this3.data,
      uiclass: _this3.childPrefix(child.props.uirole),
      filtering: _this3.handleFilter,
      sorting: _this3.handleSort,
      editing: _this3.handleEdit
    }));
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      data: _this3.data,
      uiclass: _this3.childPrefix(child.props.uirole)
    }));
  };

  this.preRenderBody = function (children, inherited) {
    var output = [];
    React.Children.map(children, function (child) {
      if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === TableBody.defaultProps.uirole) {
        output.push(_this3.renderChild(child, inherited));
      }
      return null;
    });
    return output;
  };

  this.renderPagination = function () {
    var output = [];
    if (_this3.props.pagination) {
      var pageConfig = _this3.data.getPagination(_this3);
      var uuid = _this3.props.uuid;

      output.push(React.createElement(
        TableFoot,
        { key: "tfoot_pagination_" + uuid, data: _this3.data },
        React.createElement(
          TableRow,
          { key: "td_pagination_" + uuid + "_cellrow" },
          React.createElement(
            TableCell,
            {
              key: "td_pagination_" + uuid + "_cell",
              colSpan: pageConfig.cols
            },
            React.createElement(Pagination, {
              pageTotal: pageConfig.pageTotal,
              pageNum: pageConfig.pageNum,
              onPageChange: _this3.handlePageChange
            })
          )
        )
      ));
    }
    return output;
  };
}, _temp);


export default Table;
